summaryrefslogtreecommitdiff
path: root/src/audio_core/sink.h
diff options
context:
space:
mode:
authorMerryMage <MerryMage@users.noreply.github.com>2016-08-31 16:55:10 +0100
committerMerryMage <MerryMage@users.noreply.github.com>2016-08-31 16:55:10 +0100
commit0ef4185644def3e7d99d88af3c8dd27d40660c82 (patch)
tree0a6b8f018184ea30b5b8471520bd426b6de52b65 /src/audio_core/sink.h
parent87893e6d68079ff4fa277688adb508d041944385 (diff)
sink: Change EnqueueSamples to take a pointer to a buffer instead of a std::vector
Diffstat (limited to 'src/audio_core/sink.h')
-rw-r--r--src/audio_core/sink.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/audio_core/sink.h b/src/audio_core/sink.h
index 1c881c3d2..a06fc3dcc 100644
--- a/src/audio_core/sink.h
+++ b/src/audio_core/sink.h
@@ -23,9 +23,10 @@ public:
/**
* Feed stereo samples to sink.
* @param samples Samples in interleaved stereo PCM16 format. Size of vector must be multiple of two.
*/
- virtual void EnqueueSamples(const std::vector<s16>& samples) = 0;
+ virtual void EnqueueSamples(const s16* samples, size_t sample_count) = 0;
/// Samples enqueued that have not been played yet.
virtual std::size_t SamplesInQueue() const = 0;
@@ -23,9 +23,10 @@ public:
/**
* Feed stereo samples to sink.
- * @param samples Samples in interleaved stereo PCM16 format. Size of vector must be multiple of two.
+ * @param samples Samples in interleaved stereo PCM16 format.
+ * @param sample_count Number of samples.
*/